@@ -846,7 +846,8 @@ def pbdDict_bisosRoot(
     symLink('core/bpip1', 'git/bxRepos/bisos/bpip1')
     symLink('core/bpip', 'git/bxRepos/bisos/bpip1')
     symLink('core/bxio', 'git/bxRepos/bisos/bxio')
-    symLink('core/bxso', 'git/bxRepos/bisos/bxso')    
+    symLink('core/bxso', 'git/bxRepos/bisos/bxso')
+    symLink('core/asc', 'git/bxRepos/bisos/asc')        
     symLink('core/var', 'var/core')
     symLink('core/tmp', 'tmp')
     symLink('core/log', 'log/core')
@@ -871,7 +872,10 @@ def pbdDict_bisosRoot(
     symLink('panels/blee/model', 'git/bxRepos/blee-binders/blee-model')        
     symLink('panels/bxde/core', 'git/bxRepos/blee-binders/bxde-core')
     symLink('panels/bxde/dev', 'git/bxRepos/blee-binders/bxde-dev')
-    symLink('panels/bxde/model', 'git/bxRepos/blee-binders/bxde-model')
+    symLink('panels/bisos-apps', 'git/bxRepos/blee-binders/bisos-apps')
+    symLink('panels/bisos-periphery', 'git/bxRepos/blee-binders/bisos-periphery')
+    symLink('panels/espoused', 'git/bxRepos/blee-binders/espoused')
+    symLink('panels/panelsRoot', 'git/bxRepos/blee-binders/panelsRoot')    
 
     directory('gatherer')
     directory('gatherer/here')
